==> dokuwiki-2012.10.13.tgz: dokuwiki/lib/plugins/usermanager/lang/nl/lang.php <==
<?php
/**
 * Dutch language file
 *
 * @author Wouter Schoot <wouter@schoot.org>
 * @author John de Graaff <john@de-graaff.net>
 * @author Niels Schoot <niels.schoot@quintiq.com>
 * @author Dion Nicolaas <dion@nicolaas.net>
 * @author Danny Rotsaert <danny.rotsaert@edpnet.be>
 * @author Marijn Hofstra hofstra.m@gmail.com
 * @author Matthias Carchon webmaster@c-mattic.be
 * @author Marijn Hofstra <hofstra.m@gmail.com>
 * @author Timon Van Overveldt <timonvo@gmail.com>
 * @author Jeroen
 * @author Ricardo Guijt <ricardoguijt@gmail.com>
 * @author Gerrit <klapinklapin@gmail.com>
 */
$lang['menu']                  = 'Gebruikersmanager';
$lang['noauth']                = '(gebruikersauthenticatie niet beschikbaar)';
$lang['nosupport']             = '(gebruikersmanagement niet ondersteund)';
$lang['badauth']               = 'ongeldige authenticatiemethode';
$lang['user_id']               = 'Gebruiker';
$lang['user_pass']             = 'Wachtwoord';
$lang['user_name']             = 'Volledige naam';
$lang['user_mail']             = 'E-mail';
$lang['user_groups']           = 'Groepen';
$lang['field']                 = 'Veld';
$lang['value']                 = 'Waarde';
$lang['add']                   = 'Toevoegen';
$lang['delete']                = 'Verwijder';
$lang['delete_selected']       = 'Verwijder geselecteerden';
$lang['edit']                  = 'Wijzigen';
$lang['edit_prompt']           = 'Wijzig deze gebruiker';
$lang['modify']                = 'Wijzigingen opslaan';
$lang['search']                = 'Zoek';
$lang['search_prompt']         = 'Voer zoekopdracht uit';
$lang['clear']                 = 'Verwijder zoekfilter';
$lang['filter']                = 'Filter';
$lang['summary']               = 'Weergegeven gebruikers %1$d-%2$d van %3$d gevonden. %4$d gebruikers in totaal.';
$lang['nonefound']             = 'Geen gebruikers gevonden. %d gebruikers in totaal.';
$lang['delete_ok']             = '%d gebruikers verwijderd';
$lang['delete_fail']           = '%d kon niet worden verwijderd.';
$lang['update_ok']             = 'Gebruiker succesvol gewijzigd';
$lang['update_fail']           = 'Gebruiker wijzigen mislukt';
$lang['update_exists']         = 'Gebruikersnaam veranderen mislukt, de opgegeven gebruikersnaam (%s) bestaat reeds (overige aanpassingen worden wel doorgevoerd).';
$lang['start']                 = 'start';
$lang['prev']                  = 'vorige';
$lang['next']                  = 'volgende';
$lang['last']                  = 'laatste';
$lang['edit_usermissing']      = 'Geselecteerde gebruiker niet gevonden, de opgegeven gebruikersnaam kan verwijderd zijn of elders aangepast.';
$lang['user_notify']           = 'Gebruiker notificeren';
$lang['note_notify']           = 'Notificatie-e-mails worden alleen verstuurd wanneer de gebruiker een nieuw wachtwoord wordt toegekend.';
$lang['note_group']            = 'Nieuwe gebruikers zullen aan de standaard groep (%s) worden toegevoegd als er geen groep opgegeven is.';
$lang['note_pass']             = 'Het wachtwoord wordt automatisch gegenereerd als het veld wordt leeggelaten en gebruikersnotificaties aanstaan.';
$lang['add_ok']                = 'Gebruiker succesvol toegevoegd';
$lang['add_fail']              = 'Gebruiker kon niet worden toegevoegd';
$lang['notify_ok']             = 'Notificatie-e-mail verzonden';
$lang['notify_fail']           = 'Notificatie-e-mail kon niet worden verzonden';

==> dokuwiki-2013.05.10.tgz: dokuwiki/lib/plugins/usermanager/lang/nl/lang.php <==
<?php
/**
 * Dutch language file
 *
 * @author Wouter Schoot <wouter@schoot.org>
 * @author John de Graaff <john@de-graaff.net>
 * @author Niels Schoot <niels.schoot@quintiq.com>
 * @author Dion Nicolaas <dion@nicolaas.net>
 * @author Danny Rotsaert <danny.rotsaert@edpnet.be>
 * @author Marijn Hofstra hofstra.m@gmail.com
 * @author Matthias Carchon webmaster@c-mattic.be
 * @author Marijn Hofstra <hofstra.m@gmail.com>
 * @author Timon Van Overveldt <timonvo@gmail.com>
 * @author Jeroen
 * @author Ricardo Guijt <ricardoguijt@gmail.com>
 * @author Gerrit <klapinklapin@gmail.com>
 */
$lang['menu']                  = 'Gebruikersmanager';
$lang['noauth']                = '(gebruikersauthenticatie niet beschikbaar)';
$lang['nosupport']             = '(gebruikersbeheer niet ondersteund)';
$lang['badauth']               = 'ongeldige authenticatiemethode';
$lang['user_id']               = 'Gebruiker';
$lang['user_pass']             = 'Wachtwoord';
$lang['user_name']             = 'Volledige naam';
$lang['user_mail']             = 'E-mail';
$lang['user_groups']           = 'Groepen';
$lang['field']                 = 'Veld';
$lang['value']                 = 'Waarde';
$lang['add']                   = 'Toevoegen';
$lang['delete']                = 'Verwijder';
$lang['delete_selected']       = 'Verwijder geselecteerden';
$lang['edit']                  = 'Wijzigen';
$lang['edit_prompt']           = 'Wijzig deze gebruiker';
$lang['modify']                = 'Wijzigingen opslaan';
$lang['search']                = 'Zoek';
$lang['search_prompt']         = 'Voer zoekopdracht uit';
$lang['clear']                 = 'Verwijder zoekfilter';
$lang['filter']                = 'Filter';
$lang['summary']               = 'Weergegeven gebruikers %1$d-%2$d van %3$d gevonden. %4$d gebruikers in totaal.';
$lang['nonefound']             = 'Geen gebruikers gevonden. %d gebruikers in totaal.';
$lang['delete_ok']             = '%d gebruikers verwijderd';
$lang['delete_fail']           = '%d kon niet worden verwijderd.';
$lang['update_ok']             = 'Gebruiker succesvol gewijzigd';
$lang['update_fail']           = 'Gebruiker wijzigen mislukt';
$lang['update_exists']         = 'Gebruikersnaam veranderen mislukt, de opgegeven gebruikersnaam (%s) bestaat reeds (overige aanpassingen worden wel doorgevoerd).';
$lang['start']                 = 'start';
$lang['prev']                  = 'vorige';
$lang['next']                  = 'volgende';
$lang['last']                  = 'laatste';
$lang['edit_usermissing']      = 'Geselecteerde gebruiker niet gevonden, de opgegeven gebruikersnaam kan verwijderd zijn of elders aangepast.';
$lang['user_notify']           = 'Gebruiker notificeren';
$lang['note_notify']           = 'Notificatie-e-mails worden alleen verstuurd wanneer de gebruiker een nieuw wachtwoord wordt toegekend.';
$lang['note_group']            = 'Nieuwe gebruikers zullen aan de standaard groep (%s) worden toegevoegd als er geen groep opgegeven is.';
$lang['note_pass']             = 'Het wachtwoord wordt automatisch gegenereerd als het veld wordt leeggelaten en gebruikersnotificaties aanstaan.';
$lang['add_ok']                = 'Gebruiker succesvol toegevoegd';
$lang['add_fail']              = 'Gebruiker kon niet worden toegevoegd';
$lang['notify_ok']             = 'Notificatie-e-mail verzonden';
$lang['notify_fail']           = 'Notificatie-e-mail kon niet worden verzonden';
